#!/usr/bin/perl -w

###############################################################################
# expandalias.pl 0.1 by Axel Beckert <abe@deuxchevaux.org>
# Creates mutt aliases for all given hostnames
#
# Useful, if you want to display always the name of a mailing list
# instead of getting displayed the name if an alias exists for some
# address and the address if no alias exists.
#
# Usage: expandalias.pl lists.readable > lists.mutt-usable
#
# Configuration commands: expandhost <from> <to>
#                         xalias <alias> <address>
#
# Example: 
#
#  expandhost xyz.mydomain.com www.mydomain.com ftp.mydomain.com
#  xalias friends My friends <friends@xyz.mydomain.com>
#
# will be expanded to
#
#  alias friends My friends <friends@xyz.mydomain.com>
#  alias friends-www My friends <friends@www.mydomain.com>
#  alias friends-ftp My friends <friends@ftp.mydomain.com>
#
#  Copyright (C) 1999 Axel Beckert <abe@deuxchevaux.org>
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
#  You can reach the author by snail-mail at the following address:
#  
#  Axel Beckert
#  Saarbrcker Strae 267a
#  D-66125 Saarbrcken, Germany
###############################################################################

my %toexpand;
my ($from,@to,$line,$newline,$alias,$address,$abk,@abkline);
while (<>) {
    chomp;
    if (/^expandhost\s+/) {
	print "# $_\n";
	($from,@to) = split(/\s+/,$');
	$toexpand{$from} = [ @to ];
    } elsif (/^xalias\s+/) {
	($line=$') =~ s/\s+/ /g; # Reine Kosmetik... *g*
	($alias,$address) = split(/\s+/,$line,2);
	if ($address !~ /,/) {
	    $address =~ s/^.*<[^@]+@([^>]+)>.*$/$1/ if $address =~ /<.*>/;
	    $address =~ s/^(.*\s)?[^@\s,]+@([\w.-]+)(\s.*)?$/$2/ 
		if $address !~ /<.*>/;
	    print "alias $line\n";
	    foreach (@{$toexpand{$address}}) {
		($abk = $_) =~ s/\..*$//;
		($newline = $line) =~ s/$address/$_/;
		@abkline = split(/\s+/,$newline);
		$abkline[0] .= "-$abk";
		print ("alias " . join(" ",@abkline) . "\n");
	    }
	}
    } else {
	print "$_\n";
    }
}
    

